Module: SorbetTyped::Props
- Extended by:
- T::Helpers, T::Sig
- Includes:
- Kernel, T::Props, T::Props::Constructor
- Defined in:
- lib/sorbet_typed/props.rb,
lib/sorbet_typed/props/version.rb,
lib/sorbet_typed/props/without_init_param_and_no_default_plugin.rb
Overview
an abstraction module to be included in any class to make the sorbet props interface usable. It’s just a wrapper around T::Props and T::Props::Constructor. It’s also the ancestor the custom tapioca compiler looks for when generating initializer type annotation rbis.
:reek:ModuleInitialize – we accept this here. This module defines an initialize method via T::Props::Constructor nonetheless, we only extend it. It shouldn’t really be used with other initializers anyway.
Defined Under Namespace
Modules: ClassMethods Classes: WithoutInitParamAndNoDefaultPlugin
Constant Summary collapse
- VERSION =
'1.3.32'
Instance Method Summary collapse
Instance Method Details
#initialize(hash = {}) ⇒ Object
44 45 46 47 48 49 |
# File 'lib/sorbet_typed/props.rb', line 44 def initialize(hash = {}) reject_unknown_parameters(hash) super post_props_initialize end |