Module: SorbetTyped::Props

Extended by:
T::Helpers, T::Sig
Includes:
T::Props, T::Props::Constructor
Defined in:
lib/sorbet_typed/props.rb,
lib/sorbet_typed/props/version.rb

Overview

an abstraction module to be included in any class to make the sorbet props interface usable. It’s just a wrapper around T::Props and T::Props::Constructor. It’s also the ancestor the custom tapioca compiler looks for when generating initializer type annotation rbis.

:reek:ModuleInitialize – we accept this here. This module defines an initialize method via T::Props::Constructor nonetheless, we only extend it. It shouldn’t really be used with other initializers anyway.

Constant Summary collapse

VERSION =
'1.2.14'

Instance Method Summary collapse

Instance Method Details

#initialize(*args, **kwargs) ⇒ Object



26
27
28
29
# File 'lib/sorbet_typed/props.rb', line 26

def initialize(*args, **kwargs)
  super
  post_props_initialize
end