Module: SorbetTyped::Props

Extended by:
T::Helpers
Includes:
T::Props, T::Props::Constructor
Defined in:
lib/sorbet_typed/props/version.rb,
lib/sorbet_typed/props.rb

Overview

an abstraction module to be included in any class to make the sorbet props interface usable. It’s just a wrapper around T::Props and T::Props::Constructor. It’s also the ancestor the custom tapioca compiler looks for when generating initializer type annotation rbis.

Constant Summary collapse

VERSION =
'0.1.0'